==> chromium_73.0.3683.75.orig.tar.xz: chromium-73.0.3683.75/ash/assistant/ui/main_stage/assistant_opt_in_view.h <==
// Copyright 2018 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef ASH_ASSISTANT_UI_MAIN_STAGE_ASSISTANT_OPT_IN_VIEW_H_
#define ASH_ASSISTANT_UI_MAIN_STAGE_ASSISTANT_OPT_IN_VIEW_H_

#include "base/macros.h"
#include "ui/views/controls/button/button.h"

namespace views {
class StyledLabel;
}  // namespace views

namespace ash {

// AssistantOptInDelegate ------------------------------------------------------

class AssistantOptInDelegate {
 public:
  // Invoked when the Assistant opt in button is pressed.
  virtual void OnOptInButtonPressed() = 0;

 protected:
  virtual ~AssistantOptInDelegate() = default;
};

// AssistantOptInView ----------------------------------------------------------

class AssistantOptInView : public views::View, public views::ButtonListener {
 public:
  AssistantOptInView();
  ~AssistantOptInView() override;

  // views::View:
  const char* GetClassName() const override;
  void ChildPreferredSizeChanged(views::View* child) override;
  void OnBoundsChanged(const gfx::Rect& previous_bounds) override;

  // views::ButtonListener:
  void ButtonPressed(views::Button* sender, const ui::Event& event) override;

  void set_delegate(AssistantOptInDelegate* delegate) { delegate_ = delegate; }

 private:
  void InitLayout();

  views::StyledLabel* label_;  // Owned by view hierarchy.

  AssistantOptInDelegate* delegate_ = nullptr;

  DISALLOW_COPY_AND_ASSIGN(AssistantOptInView);
};

}  // namespace ash

#endif  // ASH_ASSISTANT_UI_MAIN_STAGE_ASSISTANT_OPT_IN_VIEW_H_

==> chromium-77.0.3865.92.tar.xz: chromium-77.0.3865.92/ash/assistant/ui/main_stage/assistant_opt_in_view.h <==
// Copyright 2018 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef ASH_ASSISTANT_UI_MAIN_STAGE_ASSISTANT_OPT_IN_VIEW_H_
#define ASH_ASSISTANT_UI_MAIN_STAGE_ASSISTANT_OPT_IN_VIEW_H_

#include "ash/assistant/assistant_prefs_controller.h"
#include "base/component_export.h"
#include "base/macros.h"
#include "ui/views/controls/button/button.h"

namespace views {
class StyledLabel;
}  // namespace views

namespace ash {

class AssistantViewDelegate;

// AssistantOptInView ----------------------------------------------------------

class COMPONENT_EXPORT(ASSISTANT_UI) AssistantOptInView
    : public views::View,
      public views::ButtonListener,
      public AssistantPrefsObserver {
 public:
  explicit AssistantOptInView(AssistantViewDelegate* delegate_);
  ~AssistantOptInView() override;

  // views::View:
  const char* GetClassName() const override;
  void ChildPreferredSizeChanged(views::View* child) override;
  void OnBoundsChanged(const gfx::Rect& previous_bounds) override;

  // views::ButtonListener:
  void ButtonPressed(views::Button* sender, const ui::Event& event) override;

  // AssistantPrefsObserver:
  void OnAssistantConsentStatusUpdated(int consent_status) override;

 private:
  void InitLayout();
  void UpdateLabel(int consent_status);

  views::StyledLabel* label_;  // Owned by view hierarchy.

  views::Button* container_;

  AssistantViewDelegate* delegate_;

  DISALLOW_COPY_AND_ASSIGN(AssistantOptInView);
};

}  // namespace ash

#endif  // ASH_ASSISTANT_UI_MAIN_STAGE_ASSISTANT_OPT_IN_VIEW_H_
